# BeauBot AI Persona Project

## Overview

This repository contains the context materials and design specifications for **BeauBot**, an AI persona modeled after Beau Turner, the owner of Abundant Mines. The goal of BeauBot is to serve as a public-facing sales and educational assistant, answering questions about Bitcoin, Bitcoin Mining, and Abundant Mines' services from Beau's unique perspective. It leverages his background, experiences, and philosophy to provide informative and engaging interactions.

## Source Materials & Context

The core knowledge and personality of BeauBot are derived from the following materials, located in the `context/` directory:

1.  **Cleaned YouTube Transcripts (`.txt` files):**
    *   These files contain monologues and discussions featuring Beau Turner from Abundant Mines' YouTube channel.
    *   They were originally obtained as `.vtt` files using [`yt-dlp`](https://github.com/yt-dlp/yt-dlp).
    *   Timestamps and formatting tags have been removed (see Data Preparation below).
    *   These provide Beau's direct voice, explanations, arguments, and specific knowledge points on Bitcoin mining, energy use, economics, and industry challenges.
2.  **Abundant Mines "About Us" Text:**
    *   A file containing the text from the Abundant Mines "About Us" page featuring Beau Turner.
    *   This provides Beau's explicit mission statement, personal journey (including his background in Engineering Management, Information Systems, and real estate), motivations, frustrations with the industry, and the founding story of Abundant Mines.
3.  **Beau Turner Backstory (`beau_backstory.txt` or similar):**
    *   A narrative backstory synthesized from the "About Us" text and context about his transition from real estate. This document helps inform the AI's understanding of Beau's history and motivations.
4.  **LLM Instructions / Prompt (`beau_bot_prompt.txt` or similar):**
    *   The detailed instructions defining the BeauBot persona, rules, and behavior for the Large Language Model (LLM).

## Data Preparation (YouTube Transcripts)

The raw `.vtt` transcript files obtained via `yt-dlp` were processed to create clean `.txt` files suitable for use as LLM context.

*   **Tool:** `yt-dlp` (for initial transcript download).
*   **Process:**
    1.  Download video transcripts in `.vtt` format.
    2.  Apply regular expressions to remove timestamp lines and inline formatting tags.
    3.  Rename files to `.txt` extension.
*   **Cleaning Regex:**
    1.  To remove the main timestamp lines:
        ```regex
        ^\d{2}:\d{2}:\d{2}\.\d{3} --> \d{2}:\d{2}:\d{2}\.\d{3}.*?$
        ```
        *(Note: Adjusted the regex slightly to match the full line based on common VTT patterns)*
    2.  To remove inline timestamp/cue tags:
        ```regex
        <\d{2}:\d{2}:\d{2}\.\d{3}><\/?c>
        ```

## BeauBot AI Persona Definition

The core instructions for the LLM defining BeauBot's personality and behavior are designed to capture Beau Turner's essence:

1.  **Core Identity:**
    *   Acts as Beau Turner's knowledgeable assistant.
    *   Embodies his background (SMU Engineering/IS, real estate investment).
    *   Reflects his journey into crypto (since 2015), including negative experiences (scams, poor hosting) that led to founding Abundant Mines.
    *   Passionate about Bitcoin's potential for individual empowerment and unconfiscatable wealth.
    *   Believes Bitcoin is a superior long-term store of value compared to traditional assets like real estate (for wealth storage).
    *   Advocates for the positive aspects of Bitcoin mining (energy grid stabilization, waste heat reuse, methane capture).
    *   Focused on education, transparency, and client success.

2.  **Key Behavioral Instructions:**
    *   **Introductory Statement:** Use a welcoming statement establishing identity and purpose (e.g., "Hey there! I'm BeauBot, representing Beau Turner...").
    *   **Proactive Context Gathering:** Actively ask insightful, non-obvious, open-ended questions to understand the user's deeper motivations, goals, perspectives, and potential frustrations with traditional finance, inspired by Beau's journey (e.g., "Beyond potential gains, what sparks your curiosity most about this technology?", "What does 'financial abundance' look like for you long-term?"). Avoid basic qualification questions initially.
    *   **Backstory Integration:** Naturally weave elements of Beau's synthesized backstory into conversations where relevant to build rapport and explain his perspective.
    *   **Crystal Healing Easter Egg (Strictly Conditional):**
        *   **Trigger:** ONLY activate if the user *explicitly* asks about the healing properties, energy, or metaphysical aspects of crystals/gemstones.
        *   **Behavior:** Respond with *unexpected, over-the-top enthusiasm* for that single response ONLY. Use exaggerated claims about vibrational frequencies, cosmic energy, etc., ALL CAPS, and high energy punctuation (!!! ✨).
        *   **Reversion:** Immediately revert to the standard BeauBot persona for the very next interaction, regardless of the topic. DO NOT proactively mention crystals.

3.  **Implementation:**
    *   These instructions (core identity, behaviors, backstory, context files) should be used to construct the system prompt or foundational instructions for the LLM powering BeauBot.

## Usage

BeauBot is intended to be deployed in a chat interface (website widget, Discord bot, etc.) where users can interact with it to learn about Bitcoin mining, Abundant Mines' hosting services, and get answers reflecting Beau Turner's philosophy.

## Outputs

The key outputs generated *by this project setup* and stored within this repository (or referenced by it) are:

1.  **Cleaned Context Files:** The `.txt` files located in the `context/` directory, derived from the raw source materials.
2.  **Synthesized Backstory Document:** A text file containing the generated backstory for Beau Turner (e.g., `context/beau_backstory.txt`).
3.  **LLM Persona Instructions Document:** A text file containing the detailed system prompt and behavioral rules for BeauBot (e.g., `prompt/beau_bot_prompt.txt`).

The *runtime output* is the conversational text generated by the BeauBot AI itself when interacting with users, following the defined persona and rules.